@@ -193,7 +193,7 @@ class mappedIOs(fsmIOs):
                                         candidate = replaces[candidate.upper()]  # use the replacement
                                     else:
                                         raise ValueError("inputMap ERROR, line {}: Cannot find macro substitutions for: {}".format(lines.index(line), candidate))
-                                cmap[pattern.items()[k]] = candidate  # the map of this input has a tuple as key (pattern, strelm) and the parsed candidate as value
+                                cmap[list(pattern.items())[k]] = candidate  # the map of this input has a tuple as key (pattern, strelm) and the parsed candidate as value
                             self._map[key] = (cmap, strgen)  # add the current map (of this input) and the whole strgen to the general map (all inputs)
                         else:
                             ValueError("inputMap ERROR, line {}: Multiple or no assignations in line".format(lines.index(line)))
@@ -350,7 +350,7 @@ class fsmIO(object):
 
     # changing = last callback was a change callback
     def changing(self):
-        return self._currcb == 'change'
+        return self._currcb == 'change' and self._pval is not None
 
     # disconnecting = last callback was a connection callback due to disconnection
     def disconnecting(self):
@@ -391,7 +391,7 @@ class fsmIO(object):
                          2: "OVER THRESHOLD MAJOR ALARM"}
         if short:
             alarm_levels = {k: " ".join(v.split(' ')[-2:]) for k, v in alarm_levels.items()}
-        return alarm_levels.get(self._sevr, None)
+        return alarm_levels.get(self._sevr, 'UNKNOWN ALARM')
 
     # Return alarm thresholds
     def alarmLimits(self):
